==> buildfile_1.0.0_for_2.1_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/group/RightGroup.java <==
/*
 * 2004-10-22 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.group;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;
import org.eclipse.swt.widgets.TreeItem;
import org.eclipse.ui.editors.text.TextEditor;
import org.vivianj.eclipse.plugin.buildfile.util.BuildFileContent;

/**
 * RightGroupĳ
 */
public class RightGroup implements MouseListener {
	public TextEditor editor = null;

	public TreeItem treeItem = null;

	private String key = null;

	public final static String CREATE = "create";

	public final static String UPDATE = "update";

	public TextEditor getEditor() {
		return editor;
	}

	public void setEditor(TextEditor editor) {
		this.editor = editor;
	}

	public void createPanel(String key) {
	}

	/**
	 * 
	 * @param text
	 *            labelҪʾ
	 * @param group
	 *            parentʾ
	 * @return ´Label
	 */
	public Label createLabel(String text, Composite group) {
		Label label = new Label(group, SWT.LEFT);
		label.setText(text);
		return label;
	}

	/**
	 * TextؼĹ
	 * 
	 * @param text
	 *            textĬʾ
	 * @param group
	 *            parent
	 * @return ´Text
	 */
	public Text createText(String text, Composite group) {
		Text t_text = new Text(group, SWT.BORDER);
		t_text.setLayoutData(new GridLayout());
		GridData gridData = new GridData(GridData.GRAB_HORIZONTAL
				| GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL);
		gridData.horizontalSpan = 2;
		t_text.setLayoutData(gridData);
		t_text.setText(text);
		return t_text;
	}

	public void mouseDown(MouseEvent me) {
	}

	public void mouseUp(MouseEvent me) {
	}

	public void mouseDoubleClick(MouseEvent me) {
	}

	/**
	 * invokeSaveITextEditor,Eclipseı水ť
	 */
	public void invokeSave() {
		BuildFileContent buildFileContent = new BuildFileContent();
		buildFileContent.setTree(this.treeItem.getParent());
		buildFileContent.setEditor(editor);
		buildFileContent.refreshContent();
	}
}

==> buildfile_1.2.36_for_3.0_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/group/RightGroup.java <==
/*
 * 2004-10-22 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.group;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.MouseEvent;
import org.eclipse.swt.events.MouseListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;
import org.eclipse.swt.widgets.TreeItem;
import org.eclipse.ui.editors.text.TextEditor;
import org.vivianj.eclipse.plugin.buildfile.util.BuildFileContent;

/**
 * RightGroupĳ
 */
public class RightGroup implements MouseListener {
	public TextEditor editor = null;

	public TreeItem treeItem = null;

	private String key = null;

	public TextEditor getEditor() {
		return editor;
	}

	public void setEditor(TextEditor editor) {
		this.editor = editor;
	}

	public void createPanel() {
	}

	/**
	 * 
	 * @param text
	 *            labelҪʾ
	 * @param group
	 *            parentʾ
	 * @return ´Label
	 */
	public Label createLabel(String text, Composite group) {
		Label label = new Label(group, SWT.LEFT);
		label.setText(text);
		return label;
	}

	/**
	 * TextؼĹ
	 * 
	 * @param text
	 *            textĬʾ
	 * @param group
	 *            parent
	 * @return ´Text
	 */
	public Text createText(String text, Composite group) {
		Text t_text = new Text(group, SWT.BORDER);
		t_text.setLayoutData(new GridLayout());
		GridData gridData = new GridData(GridData.GRAB_HORIZONTAL
				| GridData.HORIZONTAL_ALIGN_FILL | GridData.VERTICAL_ALIGN_FILL);
		gridData.horizontalSpan = 2;
		t_text.setLayoutData(gridData);
		t_text.setText(text);
		return t_text;
	}

	public void mouseDown(MouseEvent me) {
	}

	public void mouseUp(MouseEvent me) {
	}

	public void mouseDoubleClick(MouseEvent me) {
	}

	/**
	 * invokeSaveITextEditor,Eclipseı水ť
	 */
	public void invokeSave() {
		BuildFileContent buildFileContent = new BuildFileContent();
		buildFileContent.setTree(this.treeItem.getParent());
		buildFileContent.setEditor(editor);
		buildFileContent.refreshContent();
	}
}
